@@ -1,6 +1,6 @@
 /* { dg-do compile } */
 /* { dg-options "-Waddress -Wattributes -Werror" } */
-/* { dg-warning "warnings being treated as errors" "" {target "*-*-*"} 0 } */
+/* { dg-message "warnings being treated as errors" "" {target "*-*-*"} 0 } */
 
 /* This is the first in a series of test cases that test the
    interaction between -Wfoo, -Werror, -Werror=foo, and #pragma GCC
@@ -9,13 +9,13 @@
 
 #pragma GCC diagnostic error "-Waddress"
 
-void __attribute__((dj)) bar() { }	/* { dg-warning "warning: .* attribute directive ignored" } */
+void __attribute__((dj)) bar() { }	/* { dg-error ".* attribute directive ignored" } */
 
 int i;
 
 void
 foo ()
 {
-  if (&i)	/* { dg-error "error: .* will always evaluate as 'true'" } */
+  if (&i)	/* { dg-error ".* will always evaluate as 'true'" } */
     grill ();
 }
